@@ -17,6 +17,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+
+#include "timermodel.h"
+
+#include "timer.h"
+
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -25,9 +30,6 @@
 
 #include <KLocalizedString>
 
-#include "timer.h"
-#include "timermodel.h"
-
 /* ~ TimerModel ~ */
 TimerModel::TimerModel(QObject *parent)
     : m_interface(new OrgKdeKclockTimerModelInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Timers"), QDBusConnection::sessionBus(), this))
@@ -36,7 +38,13 @@ TimerModel::TimerModel(QObject *parent)
         connect(m_interface, SIGNAL(timerAdded(QString)), this, SLOT(addTimer(QString)));
         connect(m_interface, SIGNAL(timerRemoved(QString)), this, SLOT(removeTimer(QString)));
     }
-    QDBusInterface *interface = new QDBusInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Timers"), QStringLiteral("org.freedesktop.DBus.Introspectable"), QDBusConnection::sessionBus(), this);
+    setConnectedToDaemon(m_interface->isValid());
+
+    QDBusInterface *interface = new QDBusInterface(QStringLiteral("org.kde.kclockd"),
+                                                   QStringLiteral("/Timers"),
+                                                   QStringLiteral("org.freedesktop.DBus.Introspectable"),
+                                                   QDBusConnection::sessionBus(),
+                                                   this);
     QDBusReply<QString> reply = interface->call(QStringLiteral("Introspect"));
     if (reply.isValid()) {
         auto xmlMsg = reply.value();
@@ -52,6 +60,15 @@ TimerModel::TimerModel(QObject *parent)
         }
     }
     interface->deleteLater();
+
+    // watch for kclockd
+    m_watcher = new QDBusServiceWatcher(QStringLiteral("org.kde.kclockd"), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+    connect(m_watcher, &QDBusServiceWatcher::serviceRegistered, this, [this]() -> void {
+        setConnectedToDaemon(true);
+    });
+    connect(m_watcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() -> void {
+        setConnectedToDaemon(false);
+    });
 }
 
 int TimerModel::rowCount(const QModelIndex &parent) const
@@ -123,3 +140,16 @@ void TimerModel::removeTimer(QString uuid)
     // don't need to check index out of bound, remove(index) takes care of that
     remove(index);
 }
+
+bool TimerModel::connectedToDaemon()
+{
+    return m_connectedToDaemon;
+}
+
+void TimerModel::setConnectedToDaemon(bool connectedToDaemon)
+{
+    if (m_connectedToDaemon != connectedToDaemon) {
+        m_connectedToDaemon = connectedToDaemon;
+        Q_EMIT connectedToDaemonChanged();
+    }
+}
